Problem/Motivation

There are class properties in \Drupal\views\Plugin\views\wizard\WizardPluginBase that violate the Drupal Coding standards. These properties are preceded by a phpcs ignore line, // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName

Steps to reproduce

Proposed resolution

Follow the scope guidelines to make children here as needed to rename and deprecate each property.
The Deprecation policy shows how to deprecate properties.

Remaining tasks

Create child issues

User interface changes

Introduced terminology

API changes

Data model changes

Release notes snippet

Comments

mac_weber’s picture

Huge patch coming

mac_weber’s picture

Status: Active » Needs review
mac_weber’s picture

There was one missing property that YesCT's script did not catch

Status: Needs review » Needs work
mac_weber’s picture

protected $validated_views was not listed in the meta issue. This the property I added on patch at comment #3

mac_weber’s picture

Issue summary: View changes

List properties to be changed

mac_weber’s picture

Issue summary: View changes

tell which property was not listed at meta issue

yesct’s picture

Status: Needs work » Needs review
StatusFileSize
new7.53 KB

looking at what config files were changed.
trying to see when we should change properties that effect config or not.

147 yml files

--- a/core/modules/action/tests/action_bulk_test/config/views.view.test_bulk_form.yml
--- a/core/modules/aggregator/config/views.view.aggregator_rss_feed.yml
--- a/core/modules/aggregator/tests/modules/aggregator_test_views/test_views/views.view.test_aggregator_items.yml
--- a/core/modules/block/block.routing.yml
--- a/core/modules/block/tests/modules/block_test_views/test_views/views.view.test_view_block.yml
--- a/core/modules/block/tests/modules/block_test_views/test_views/views.view.test_view_block2.yml
--- a/core/modules/comment/comment.routing.yml
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_row.yml
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_rss.yml
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_comment_user_uid.yml
--- a/core/modules/config/tests/config_test/config_test.routing.yml
--- a/core/modules/contact/tests/modules/contact_test_views/test_views/views.view.test_contact_link.yml
--- a/core/modules/content_translation/tests/modules/content_translation_test_views/test_views/views.view.test_entity_translations_link.yml
--- a/core/modules/edit/edit.routing.yml
--- a/core/modules/editor/editor.routing.yml
--- a/core/modules/entity/entity.routing.yml
--- a/core/modules/entity_reference/entity_reference.routing.yml
--- a/core/modules/entity_reference/tests/modules/entity_reference_test/config/views.view.test_entity_reference.yml
--- a/core/modules/field/config/schema/field.schema.yml
--- a/core/modules/field/tests/modules/field_test_config/config/field.instance.entity_test.entity_test.field_test_import.yml
--- a/core/modules/field/tests/modules/field_test_config/config/field.instance.entity_test.entity_test.field_test_import_2.yml
--- a/core/modules/field/tests/modules/field_test_config/config/field.instance.entity_test.test_bundle.field_test_import_2.yml
--- a/core/modules/field/tests/modules/field_test_config/staging/field.instance.entity_test.entity_test.field_test_import_staging.yml
--- a/core/modules/field/tests/modules/field_test_config/staging/field.instance.entity_test.test_bundle.field_test_import_staging_2.yml
--- a/core/modules/field/tests/modules/field_test_config/staging/field.instance.entity_test.test_bundle_2.field_test_import_staging_2.yml
--- a/core/modules/field/tests/modules/field_test_views/test_views/views.view.test_view_fieldapi.yml
--- a/core/modules/file/config/views.view.files.yml
--- a/core/modules/file/tests/modules/file_test_views/test_views/views.view.file_extension_view.yml
--- a/core/modules/filter/filter.routing.yml
--- a/core/modules/forum/tests/modules/forum_test_views/test_views/views.view.test_forum_index.yml
--- a/core/modules/node/config/views.view.content.yml
--- a/core/modules/node/config/views.view.frontpage.yml
--- a/core/modules/node/node.routing.yml
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_type.yml
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_filter_node_uid_revision.yml
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_bulk_form.yml
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_revision_nid.yml
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_revision_vid.yml
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_row_plugin.yml
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_node_view.yml
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_status_extra.yml
--- a/core/modules/rest/tests/modules/rest_test_views/test_views/views.view.test_serializer_display_entity.yml
--- a/core/modules/rest/tests/modules/rest_test_views/test_views/views.view.test_serializer_display_field.yml
--- a/core/modules/statistics/tests/modules/statistics_test_views/test_views/views.view.test_statistics_integration.yml
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_filter_taxonomy_index_tid.yml
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_groupwise_term.yml
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.test_taxonomy_node_term_data.yml
--- a/core/modules/tracker/tests/modules/tracker_test_views/test_views/views.view.test_tracker_user_uid.yml
--- a/core/modules/user/config/views.view.user_admin_people.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_access_perm.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_access_role.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_field_permission.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_filter_permission.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_groupwise_user.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_plugin_argument_default_current_user.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_bulk_form.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_data.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_name.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_relationship.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_user_uid_argument.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_view_argument_validate_user.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_views_handler_field_role.yml
--- a/core/modules/user/tests/modules/user_test_views/test_views/views.view.test_views_handler_field_user_name.yml
--- a/core/modules/views/config/schema/views.schema.yml
--- a/core/modules/views/config/views.view.archive.yml
--- a/core/modules/views/config/views.view.backlinks.yml
--- a/core/modules/views/config/views.view.comments_recent.yml
--- a/core/modules/views/config/views.view.glossary.yml
--- a/core/modules/views/config/views.view.taxonomy_term.yml
--- a/core/modules/views/config/views.view.tracker.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_access_none.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_aggregate_count.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_alias.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_area_title.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_date.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_default_current_user.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_default_fixed.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_attachment_ui.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_cache.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_click_sort.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_destroy.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_display.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_display_attachment.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_display_defaults.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_display_invalid.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_display_more.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_dropbutton.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_area.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_row.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_type_filter.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_example_area.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_executable_displays.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_exposed_admin_ui.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_exposed_block.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_exposed_form.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_feed_display.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_classes.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_get_entity.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_output.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_tokens.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_field_type.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_filter.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_filter_date_between.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_filter_group_override.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_filter_groups.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_filter_in_operator_ui.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_get_attach_displays.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_glossary.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_grid.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_group_by_count.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_group_by_in_filters.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_handler_relationships.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_handler_test_access.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_history.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_http_status_code.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_mini_pager.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_page_display.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_page_display_arguments.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_page_display_menu.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_page_display_route.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_page_view.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_pager_full.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_pager_none.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_pager_some.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_preview.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_redirect_view.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_reset_button.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_simple_argument.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_store_pager_settings.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_style_mapping.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_table.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_tokens.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_argument_validate_numeric.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_argument_validate_php.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_delete.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_display_template.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_empty.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_handler_weight.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_pager_full_zero_items_per_page.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_render.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_status.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_view_storage.yml
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_views_groupby_save.yml
--- a/core/modules/views/tests/modules/views_test_data/test_views/views.view.test_access_static.yml
--- a/core/profiles/standard/config/field.instance.node.article.field_image.yml
--- a/core/profiles/standard/config/field.instance.node.article.field_tags.yml

23 of those are not for tests

--- a/core/modules/aggregator/config/views.view.aggregator_rss_feed.yml
--- a/core/modules/block/block.routing.yml
--- a/core/modules/comment/comment.routing.yml
--- a/core/modules/edit/edit.routing.yml
--- a/core/modules/editor/editor.routing.yml
--- a/core/modules/entity/entity.routing.yml
--- a/core/modules/entity_reference/entity_reference.routing.yml
--- a/core/modules/field/config/schema/field.schema.yml
--- a/core/modules/file/config/views.view.files.yml
--- a/core/modules/filter/filter.routing.yml
--- a/core/modules/node/config/views.view.content.yml
--- a/core/modules/node/config/views.view.frontpage.yml
--- a/core/modules/node/node.routing.yml
--- a/core/modules/user/config/views.view.user_admin_people.yml
--- a/core/modules/views/config/schema/views.schema.yml
--- a/core/modules/views/config/views.view.archive.yml
--- a/core/modules/views/config/views.view.backlinks.yml
--- a/core/modules/views/config/views.view.comments_recent.yml
--- a/core/modules/views/config/views.view.glossary.yml
--- a/core/modules/views/config/views.view.taxonomy_term.yml
--- a/core/modules/views/config/views.view.tracker.yml
--- a/core/profiles/standard/config/field.instance.node.article.field_image.yml
--- a/core/profiles/standard/config/field.instance.node.article.field_tags.yml

here is a sample

diff --git a/core/modules/comment/comment.routing.yml b/core/modules/comment/comment.routing.yml
index 7768cd0..69e6502 100644
--- a/core/modules/comment/comment.routing.yml
+++ b/core/modules/comment/comment.routing.yml
@@ -9,7 +9,7 @@ comment_approve:
   pattern: '/comment/{comment}/approve'
   defaults:
     _content: '\Drupal\comment\Controller\CommentController::commentApprove'
-    entity_type: 'comment'
+    entityType: 'comment'
   requirements:
     _entity_access: 'comment.approve'

attached is just the changes to the original class file. letting the bot test it so we can see where it causes fails.

and below is just the property definitions with more context lines (got with: git diff -U7)

diff --git a/core/modules/comment/lib/Drupal/comment/Entity/Comment.php b/core/modules/comment/lib/Drupal/comment/Entity/Comment.php
index 59c122b..9e14990 100644
--- a/core/modules/comment/lib/Drupal/comment/Entity/Comment.php
+++ b/core/modules/comment/lib/Drupal/comment/Entity/Comment.php
@@ -32,7 +32,7 @@
  *     },
  *     "translation" = "Drupal\comment\CommentTranslationController"
  *   },
- *   base_table = "comment",
+ *   baseTable = "comment",
  *   uri_callback = "comment_uri",
  *   fieldable = TRUE,
  *   translatable = TRUE,
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/entity_reference/selection/CommentSelection.php b/core/modules/comment/lib/Drupal/comment/Plugin/entity_reference/selection/CommentSelection.php
index fff8d59..28622c5 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/entity_reference/selection/CommentSelection.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/entity_reference/selection/CommentSelection.php
@@ -45,7 +45,7 @@ public function buildEntityQuery($match = NULL, $match_operator = 'CONTAINS') {
    */
   public function entityQueryAlter(SelectInterface $query) {
     $tables = $query->getTables();
-    $base_table = $tables['base_table']['alias'];
+    $base_table = $tables['baseTable']['alias'];

     // The Comment module doesn't implement any proper comment access,
     // and as a consequence doesn't make sure that comments cannot be viewed

b) is only a part of that, just in the WizardPluginBase class file (but done from that with comments option checked).

c) Then thought.. hm. let's try it without the comments option, see what files are changed. and compare the two diffs, at least compare the files changed. I think we just want to change the comments that are in files that are changed when we refactor without the comments option. (only change comments in files that are changed, and look at each of those to see if they make sense to change.) http://screencast.com/t/MblkHFeLx

Here is a diff of b (with comments) and c (without comments):

$ diff *7b.patch *7c.patch
2c2
< index c3ccf92..72b16b2 100644
---
> index c3ccf92..b7bc2b0 100644
19c19
< +    $this->baseTable = $this->definition['baseTable'];
---
> +    $this->baseTable = $this->definition['base_table'];
24c24
< +      if (isset($entity_info['baseTable']) && $this->baseTable == $entity_info['baseTable']) {
---
> +      if (isset($entity_info['base_table']) && $this->baseTable == $entity_info['base_table']) {
53c53
< +      'baseTable' => $this->baseTable,
---
> +      'base_table' => $this->baseTable,

Those are the things I think we should look at.

yesct’s picture

Here is a easier to read diff of 7b and 7c.

7c might be good. an irc conversation with @tim.plunkett helped me figure out where the ['base_table'] part of the definition array is coming from.

tl;dr
annotation in core/modules/views/lib/Drupal/views/Annotation/ViewsWizard.php

tim also said "we don't use camel case in annotation strings"

---- notes ----

notes from trying to find ['base_table']:

In the WizardPluginBase

  /**
   * Constructs a WizardPluginBase object.
   */
  public function __construct(array $configuration, $plugin_id, array $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->baseTable = $this->definition['base_table'];

it is expecting a definition property, but we are not setting definition here. So it must be set in the parent when the parent::__construct is called.

To find the parent, I looked at the class definition:
abstract class WizardPluginBase extends PluginBase implements WizardInterface {

(at first I opened the wrong PluginBase... but then looked in the WizardPluginBase use statements)
use Drupal\views\Plugin\views\PluginBase;

in core/modules/views/lib/Drupal/views/Plugin/views/PluginBase.php
it has a definition property


  /**
   * Plugins's definition
   *
   * @var array
   */
  public $definition;

so I looked to see where the ['base_table'] part of definition was set. Its constructor is

  /**
   * Constructs a Plugin object.
   */
  public function __construct(array $configuration, $plugin_id, array $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->definition = $plugin_definition + $configuration;
  }

So it comes from $plugin_definition or $configuration.

Looking to see where and when in those, I did not see it.

The create is just

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, array $plugin_definition) {
    return new static($configuration, $plugin_id, $plugin_definition);
  }

I thought maybe from something it extends.
abstract class PluginBase extends ComponentPluginBase implements ContainerFactoryPluginInterface {

but could not find ComponentPluginBase. Turns out it is an alias
use Drupal\Component\Plugin\PluginBase as ComponentPluginBase;

But did not find 'base_table' in core/lib/Drupal/Component/Plugin/PluginBase.php either.

sooo... where is it coming from? tim pointed to an example that extends WizardPluginBase:

/**
 * Tests creating node views with the wizard.
 *
 * @ViewsWizard(
 *   id = "node",
 *   module = "node",
 *   base_table = "node",
 *   title = @Translation("Content")
 * )
 */
class Node extends WizardPluginBase {

So it is in an annotation.
The annotation comes from core/modules/views/lib/Drupal/views/Annotation/ViewsWizard.php

I wondered how I could know that, besides guessing that I should look for something that extends it...

* We thought adding a @see to all of the base classes to their annotation classes would be a good idea (and needs to be a separate issue).

And, this means that since the annotations are not using camelCase, and this issue is not about core/modules/views/lib/Drupal/views/Annotation/ViewsWizard.php anyway, we should keep it like 7c, because those are parts of the definition array.

yesct’s picture

StatusFileSize
new1.78 KB

forgot the diff. oops. here it is.

_12345678912345678’s picture

_12345678912345678’s picture

Issue summary: View changes

added file name and link to drupalcode

alansaviolobo’s picture

Issue summary: View changes
StatusFileSize
new7.85 KB

reroll

yesct’s picture

Did you reroll (apply the old patch when it applied and then merge with head) for 7c? Or did you make a new patch from scratch using a IDE to refactor?

yesct’s picture

Assigned: mac_weber » Unassigned

unassigning since it's been a while since @Mac_Weber worked on this one. Just comment back, make a new patch, or review to jump back into it.

yesct’s picture

+++ b/core/modules/views/src/Plugin/views/wizard/WizardPluginBase.php
@@ -1158,11 +1158,11 @@ protected function pageFeedDisplayOptions($form, FormStateInterface $form_state)
-   * @param \Drupal\views\View\plugin\display\DisplayPluginBase $display
+   * @param \Drupal\views\Plugin\views\display\DisplayPluginBase $display
...
-   * @param \Drupal\views\View\plugin\display\DisplayPluginBase $default_display
+   * @param \Drupal\views\plugin\views\display\DisplayPluginBase $default_display

@@ -1194,11 +1194,11 @@ protected function setDefaultOptions($options, DisplayPluginBase $display, Displ
-   * @param \Drupal\views\View\plugin\display\DisplayPluginBase $display
+   * @param \Drupal\views\plugin\Views\display\DisplayPluginBase $display
...
-   * @param \Drupal\views\View\plugin\display\DisplayPluginBase $default_display
+   * @param \Drupal\views\plugin\Views\display\DisplayPluginBase $default_display

these look like unrelated changes to this issue. If those full paths need to be changed it should be done in a separate issue.

yesct’s picture

Issue summary: View changes
Status: Needs review » Needs work

Since this is a normal task,
doing https://www.drupal.org/contributor-tasks/update-allowed-beta
to evaluate for https://www.drupal.org/contribute/core/beta-changes

This is not critical,
not one of the unfrozen areas only,
not a prioritized change,
not a major,

which means, this should be done in 8.0.x only *if* it reduces fragility.

Additionally, certain changes that reduce fragility are also prioritized. For example: Narrowing an API, removing unused and untested functionality, correcting misspelled or wholly inaccurate method names. Whether or not an issue reduces fragility is at core maintainer discretion and should be discussed on a case-by-case basis.

This doesn't sound like that...

But it also is not disruptive, since the properties are already protected, and would be isolated to internal to this class.

So I think this would only get in the beta under "not disruptive".

[edit:]
See #1518116-86: [meta] Make Core pass Coder Review for related coding standard postponing discussion

alansaviolobo’s picture

I tried applying the patch first. but since it conflicted and didn't change all the occurrences, I preferred to start from scratch.

yesct’s picture

for the out of scope changes noted in #14:
#2376403: Some full name space paths wrong in comments in WizardPluginBase

diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php b/core/modules/views/lib/Drupal/v
index c3ccf92..5b57d34 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php
@@ -24,39 +24,39 @@
 abstract class WizardPluginBase extends PluginBase implements WizardInterface {
 
   /**
    * The base table connected with the wizard.
    *
    * @var string
    */
-  protected $base_table;
+  protected $baseTable;
 
   /**
    * The entity type connected with the wizard.
    *
    * There might be base tables connected with entity types, if not this would
    * be empty.
    *
    * @var string
    */
-  protected $entity_type;
+  protected $entityType;
 
   /**
    * Contains the information from entity_get_info of the $entity_type.
    *
    * @var array
    */
-  protected $entity_info = array();
+  protected $entityInfo = array();
 
   /**
    * An array of validated view objects, keyed by a hash.
    *
    * @var array
    */
-  protected $validated_views = array();
+  protected $validatedViews = array();
 
   /**
    * The table column used for sorting by create date of this wizard.
    *
    * @var string
    */
   protected $createdColumn;
@@ -100,33 +100,33 @@
    * Default values for filters.
    *
    * By default, filters are not exposed and added to the first non-reserved
    * filter group.
    *
    * @var array()
    */
-  protected $filter_defaults = array(
+  protected $filterDefaults = array(
     'id' => NULL,
     'expose' => array('operator' => FALSE),
     'group' => 1,
@@ -24,39 +24,39 @@
 
   /**
-   * Contains the information from entity_get_info of the $entity_type.
+   * Contains the information from entity_get_info of the $entityType.
    *
    * @var array
   );

I'm not sure that entity type change in comments is the same entity type from this views wizard class. Maybe a too wide search and replace was done.

I'm going to try the phpstorm refactor and see what I get.

yesct’s picture

a) Did just one property the base table property, with the "in comments" option selected in phpstorm refactor rename. http://screencast.com/t/EbrFc12x0

It changed many files.

Here is a snip of a couple:

--
note this issue needs to have those changes removed from this patch.

when doing that, the instructions for an interdiff will probably be useful https://www.drupal.org/documentation/git/interdiff

alansaviolobo’s picture

StatusFileSize
new1.99 KB
new5.98 KB

@YesCT, thanks for your suggestions. have removed the changes to the file paths.

alansaviolobo’s picture

Status: Needs work » Needs review
mac_weber’s picture

Status: Needs review » Reviewed & tested by the community
alexpott’s picture

Version: 8.0.x-dev » 8.1.x-dev
Status: Reviewed & tested by the community » Postponed
Parent issue: » #2052421: [META] Rename Views properties to core standards

I have just postponed all the rest of #2052421: [META] Rename Views properties to core standards's child issues. This was the only issue at RTBC. I've checked that the properties being changed here are only used in the base class. This change is not disruptive BUT it is not allowable according to the beta rules. It has been worked on since 31 Aug 2013 and maybe I would have committed it if this was @alansaviolobo's, @Mac_Weber's or @YesCT's first commit credit. I'm not enjoying postponing this issue but we've come up with a process and we should stick to it. Sorry.

Version: 8.1.x-dev » 8.2.x-dev

Drupal 8.1.0-beta1 was released on March 2, 2016, which means new developments and disruptive changes should now be targeted against the 8.2.x-dev branch. For more information see the Drupal 8 minor version schedule and the Allowed changes during the Drupal 8 release cycle.

Version: 8.2.x-dev » 8.3.x-dev

Drupal 8.2.0-beta1 was released on August 3, 2016, which means new developments and disruptive changes should now be targeted against the 8.3.x-dev branch. For more information see the Drupal 8 minor version schedule and the Allowed changes during the Drupal 8 release cycle.

Version: 8.3.x-dev » 8.4.x-dev

Drupal 8.3.0-alpha1 will be released the week of January 30, 2017, which means new developments and disruptive changes should now be targeted against the 8.4.x-dev branch. For more information see the Drupal 8 minor version schedule and the Allowed changes during the Drupal 8 release cycle.

Version: 8.4.x-dev » 8.5.x-dev

Drupal 8.4.0-alpha1 will be released the week of July 31, 2017, which means new developments and disruptive changes should now be targeted against the 8.5.x-dev branch. For more information see the Drupal 8 minor version schedule and the Allowed changes during the Drupal 8 release cycle.

Version: 8.5.x-dev » 8.6.x-dev

Drupal 8.5.0-alpha1 will be released the week of January 17, 2018, which means new developments and disruptive changes should now be targeted against the 8.6.x-dev branch. For more information see the Drupal 8 minor version schedule and the Allowed changes during the Drupal 8 release cycle.

Version: 8.6.x-dev » 8.7.x-dev

Drupal 8.6.0-alpha1 will be released the week of July 16, 2018, which means new developments and disruptive changes should now be targeted against the 8.7.x-dev branch. For more information see the Drupal 8 minor version schedule and the Allowed changes during the Drupal 8 release cycle.

Version: 8.7.x-dev » 8.8.x-dev

Drupal 8.7.0-alpha1 will be released the week of March 11, 2019, which means new developments and disruptive changes should now be targeted against the 8.8.x-dev branch. For more information see the Drupal 8 minor version schedule and the Allowed changes during the Drupal 8 release cycle.

Version: 8.8.x-dev » 8.9.x-dev

Drupal 8.8.0-alpha1 will be released the week of October 14th, 2019, which means new developments and disruptive changes should now be targeted against the 8.9.x-dev branch. (Any changes to 8.9.x will also be committed to 9.0.x in preparation for Drupal 9’s release, but some changes like significant feature additions will be deferred to 9.1.x.). For more information see the Drupal 8 and 9 minor version schedule and the Allowed changes during the Drupal 8 and 9 release cycles.

Version: 8.9.x-dev » 9.1.x-dev

Drupal 8.9.0-beta1 was released on March 20, 2020. 8.9.x is the final, long-term support (LTS) minor release of Drupal 8, which means new developments and disruptive changes should now be targeted against the 9.1.x-dev branch. For more information see the Drupal 8 and 9 minor version schedule and the Allowed changes during the Drupal 8 and 9 release cycles.

vsujeetkumar’s picture

Status: Needs review » Needs work
Issue tags: +Needs reroll

Above patch fail to apply, Need Re-roll.

vsujeetkumar’s picture

Assigned: Unassigned » vsujeetkumar
vsujeetkumar’s picture

Assigned: vsujeetkumar » Unassigned
Status: Needs work » Needs review
Issue tags: -Needs reroll
StatusFileSize
new6.29 KB

Re-roll patch created, Please review.

Status: Needs review » Needs work

The last submitted patch, 34: 2078593_34.patch, failed testing. View results

vsujeetkumar’s picture

Status: Needs work » Needs review
StatusFileSize
new6.92 KB
new485 bytes

Fixed the test, Please review.

andypost’s picture

Great to see tests pass,, now it needs Deprecated property trait and tests to make sure contrib can catch this rename while backward compatibility is preserved

Version: 9.1.x-dev » 9.2.x-dev

Drupal 9.1.0-alpha1 will be released the week of October 19, 2020, which means new developments and disruptive changes should now be targeted for the 9.2.x-dev branch. For more information see the Drupal 9 minor version schedule and the Allowed changes during the Drupal 9 release cycle.

Version: 9.2.x-dev » 9.3.x-dev

Drupal 9.2.0-alpha1 will be released the week of May 3, 2021, which means new developments and disruptive changes should now be targeted for the 9.3.x-dev branch. For more information see the Drupal core minor version schedule and the Allowed changes during the Drupal core release cycle.

Version: 9.3.x-dev » 9.4.x-dev

Drupal 9.3.0-rc1 was released on November 26, 2021, which means new developments and disruptive changes should now be targeted for the 9.4.x-dev branch. For more information see the Drupal core minor version schedule and the Allowed changes during the Drupal core release cycle.

Version: 9.4.x-dev » 9.5.x-dev

Drupal 9.4.0-alpha1 was released on May 6, 2022, which means new developments and disruptive changes should now be targeted for the 9.5.x-dev branch. For more information see the Drupal core minor version schedule and the Allowed changes during the Drupal core release cycle.

Version: 9.5.x-dev » 10.1.x-dev

Drupal 9.5.0-beta2 and Drupal 10.0.0-beta2 were released on September 29, 2022, which means new developments and disruptive changes should now be targeted for the 10.1.x-dev branch. For more information see the Drupal core minor version schedule and the Allowed changes during the Drupal core release cycle.

needs-review-queue-bot’s picture

Status: Needs review » Needs work
StatusFileSize
new144 bytes

The Needs Review Queue Bot tested this issue. It either no longer applies to Drupal core, or fails the Drupal core commit checks. Therefore, this issue status is now "Needs work".

Apart from a re-roll or rebase, this issue may need more work to address feedback in the issue or MR comments. To progress an issue, incorporate this feedback as part of the process of updating the issue. This helps other contributors to know what is outstanding.

Consult the Drupal Contributor Guide to find step-by-step guides for working with issues.

quietone’s picture

Status: Needs work » Postponed

This is a coding standard fix and they are now done by sniff, not file. See #3346468: [meta] Fix class properties violating Drupal.NamingConventions.ValidVariableName.LowerCamelName

Version: 10.1.x-dev » 11.x-dev

Drupal core is moving towards using a “main” branch. As an interim step, a new 11.x branch has been opened, as Drupal.org infrastructure cannot currently fully support a branch named main. New developments and disruptive changes should now be targeted for the 11.x branch, which currently accepts only minor-version allowed changes. For more information, see the Drupal core minor version schedule and the Allowed changes during the Drupal core release cycle.

quietone’s picture

Component: views.module » other
Issue summary: View changes
Status: Postponed » Active
Issue tags: +Coding standards

Version: 11.x-dev » main

Drupal core is now using the main branch as the primary development branch. New developments and disruptive changes should now be targeted to the main branch.

Read more in the announcement.